# Branching Strategy

## Overview
This document outlines the branching strategy for this Drupal-based project. The approach is designed to support parallel development aligned with Drupal's minor version releases, such as `10.1.x` or `10.2.x`. This strategy ensures smooth transitions and continuous integration during Drupal's lifecycle.

## Branching Model

### Minor Version Branches
- **Purpose**: Each minor version of Drupal will have a corresponding branch in our repository (e.g., `10.1.x`, `10.2.x`). These branches allow for parallel development against different versions of Drupal Core.
- **Usage**: Use these branches for development that is specific to a particular Drupal minor version.
- Mark the current production version branch as the main branch in Bitbucket
- The `master` branch is not used.

## Workflow

### Development Workflow
1. **Feature Branches**: Create feature branches from the relevant minor version branch, not from `master`.
2. **Pull Requests**: Merge feature branches back into the corresponding minor version branch(s) upon completion and review.

### Updating Production

1. **Tagging Releases**: When a release is ready for production, tag it with the current date in the format `YYYY-MM-DD`.
2. **Deploy the tag**: Using Bitbucket Pipelines or git commands deploy the tagged commit to the production environment.

### Backporting Commits

- **Cherry-Picking**: To maintain parallel development across different Drupal versions, backport commits to other relevant minor version branches using `git cherry-pick` as necessary.
- **Consistency**: Ensure that critical updates are consistently applied across all active minor version branches.

## Best Practices
- Regularly update your local branches to reflect the latest changes in the remote repository.
- Before starting new work, ensure you're on the correct minor version branch.
- Test changes thoroughly in a development environment before tagging a production release.
- Communicate with the team when making significant changes or when backporting commits to avoid conflicts.

## Additional Resources
- [Git Cherry-Pick Documentation](https://git-scm.com/docs/git-cherry-pick)
- [Drupal Release Cycle](https://www.drupal.org/docs/understanding-drupal/drupal-release-cycle)
